@@ -1,4 +1,4 @@
-from pygraham import *
+from pygraham.pygraham import *
 
 __all__ = [
     'list',
